@@ -2,7 +2,7 @@ from .bottom_up_eval import (aggregate_results, get_group_preds,
                              get_multi_stage_outputs)
 from .eval_hooks import DistEvalHook, EvalHook
 from .mesh_eval import compute_similarity_transform
-from .pose3d_eval import keypoint_mpjpe
+from .pose3d_eval import keypoint_3d_auc, keypoint_3d_pck, keypoint_mpjpe
 from .top_down_eval import (keypoint_auc, keypoint_epe, keypoint_pck_accuracy,
                             keypoints_from_heatmaps, keypoints_from_heatmaps3d,
                             keypoints_from_regression,
@@ -15,5 +15,5 @@ __all__ = [
     'keypoint_epe', 'get_group_preds', 'get_multi_stage_outputs',
     'aggregate_results', 'compute_similarity_transform', 'post_dark_udp',
     'keypoint_mpjpe', 'keypoints_from_heatmaps3d',
-    'multilabel_classification_accuracy'
+    'multilabel_classification_accuracy', 'keypoint_3d_pck', 'keypoint_3d_auc'
 ]
