@@ -4,7 +4,7 @@ from collections import OrderedDict
 import json_tricks as json
 import numpy as np
 
-from mmpose.core.evaluation.mesh_eval import compute_similarity_transform
+from mmpose.core.evaluation import keypoint_mpjpe
 from mmpose.datasets.builder import DATASETS
 from .mesh_base_dataset import MeshBaseDataset
 
@@ -37,15 +37,13 @@ class MeshH36MDataset(MeshBaseDataset):
 
         res_file = os.path.join(res_folder, 'result_keypoints.json')
         kpts = []
-        for preds, boxes, image_path in outputs:
-            kpts.append({
-                'keypoints': preds[0].tolist(),
-                'center': boxes[0][0:2].tolist(),
-                'scale': boxes[0][2:4].tolist(),
-                'area': float(boxes[0][4]),
-                'score': float(boxes[0][5]),
-                'image': image_path,
-            })
+        for out in outputs:
+            for (keypoints, image_path) in zip(out['keypoints_3d'],
+                                               out['image_path']):
+                kpts.append({
+                    'keypoints': keypoints.tolist(),
+                    'image': image_path,
+                })
 
         self._write_keypoint_results(kpts, res_file)
         info_str = self._report_metric(res_file)
@@ -70,46 +68,33 @@ class MeshH36MDataset(MeshBaseDataset):
             preds = json.load(fin)
         assert len(preds) == len(self.db)
 
-        joint_error = []
-        joint_error_pa = []
+        pred_joints_3d = [pred['keypoints'] for pred in preds]
+        gt_joints_3d = [item['joints_3d'] for item in self.db]
+        gt_joints_visible = [item['joints_3d_visible'] for item in self.db]
 
-        for pred, item in zip(preds, self.db):
-            error, error_pa = self.evaluate_kernel(pred['keypoints'][0],
-                                                   item['joints_3d'],
-                                                   item['joints_3d_visible'])
-            joint_error.append(error)
-            joint_error_pa.append(error_pa)
+        pred_joints_3d = np.array(pred_joints_3d)
+        gt_joints_3d = np.array(gt_joints_3d)
+        gt_joints_visible = np.array(gt_joints_visible)
 
-        mpjpe = np.array(joint_error).mean()
-        mpjpe_pa = np.array(joint_error_pa).mean()
+        # we only evaluate on 14 lsp joints
+        joint_mapper = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 18]
+        pred_joints_3d = pred_joints_3d[:, joint_mapper, :]
+        pred_pelvis = (pred_joints_3d[:, 2] + pred_joints_3d[:, 3]) / 2
+        pred_joints_3d = pred_joints_3d - pred_pelvis[:, None, :]
+
+        gt_joints_3d = gt_joints_3d[:, joint_mapper, :]
+        gt_pelvis = (gt_joints_3d[:, 2] + gt_joints_3d[:, 3]) / 2
+        gt_joints_3d = gt_joints_3d - gt_pelvis[:, None, :]
+        gt_joints_visible = gt_joints_visible[:, joint_mapper, 0] > 0
+
+        mpjpe = keypoint_mpjpe(pred_joints_3d, gt_joints_3d, gt_joints_visible)
+        mpjpe_pa = keypoint_mpjpe(
+            pred_joints_3d,
+            gt_joints_3d,
+            gt_joints_visible,
+            alignment='procrustes')
 
         info_str = []
         info_str.append(('MPJPE', mpjpe * 1000))
         info_str.append(('MPJPE-PA', mpjpe_pa * 1000))
         return info_str
-
-    @staticmethod
-    def evaluate_kernel(pred_joints_3d, joints_3d, joints_3d_visible):
-        """Evaluate one example."""
-        # Only 14 lsp joints are used for evaluation
-        joint_mapper = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 18]
-        assert joints_3d_visible[joint_mapper].min() > 0
-
-        pred_joints_3d = np.array(pred_joints_3d)
-        pred_joints_3d = pred_joints_3d[joint_mapper, :]
-        pred_pelvis = (pred_joints_3d[[2]] + pred_joints_3d[[3]]) / 2
-        pred_joints_3d = pred_joints_3d - pred_pelvis
-
-        gt_joints_3d = joints_3d[joint_mapper, :]
-        gt_pelvis = (gt_joints_3d[[2]] + gt_joints_3d[[3]]) / 2
-        gt_joints_3d = gt_joints_3d - gt_pelvis
-
-        error = pred_joints_3d - gt_joints_3d
-        error = np.linalg.norm(error, ord=2, axis=-1).mean(axis=-1)
-
-        pred_joints_3d_aligned = compute_similarity_transform(
-            pred_joints_3d, gt_joints_3d)
-        error_pa = pred_joints_3d_aligned - gt_joints_3d
-        error_pa = np.linalg.norm(error_pa, ord=2, axis=-1).mean(axis=-1)
-
-        return error, error_pa
