@@ -2,6 +2,7 @@ from .alexnet import AlexNet
 from .cpm import CPM
 from .hourglass import HourglassNet
 from .hrnet import HRNet
+from .litehrnet import LiteHRNet
 from .mobilenet_v2 import MobileNetV2
 from .mobilenet_v3 import MobileNetV3
 from .mspn import MSPN
@@ -23,5 +24,5 @@ __all__ = [
     'AlexNet', 'HourglassNet', 'HRNet', 'MobileNetV2', 'MobileNetV3', 'RegNet',
     'ResNet', 'ResNetV1d', 'ResNeXt', 'SCNet', 'SEResNet', 'SEResNeXt',
     'ShuffleNetV1', 'ShuffleNetV2', 'CPM', 'RSN', 'MSPN', 'ResNeSt', 'VGG',
-    'TCN', 'ViPNAS_ResNet'
+    'TCN', 'ViPNAS_ResNet', 'LiteHRNet'
 ]
